import { Disposable } from "vscode/vscode/vs/base/common/lifecycle";
import { IStorageDatabase } from "vscode/vscode/vs/base/parts/storage/common/storage";
import { IStorageValueChangeEvent, StorageTarget } from "vscode/vscode/vs/platform/storage/common/storage";
import { IStorageService } from "vscode/vscode/vs/platform/storage/common/storage.service";
import { Event } from "vscode/vscode/vs/base/common/event";
import { IRemoteService } from "vscode/vscode/vs/platform/ipc/common/services";
import { ILogService } from "vscode/vscode/vs/platform/log/common/log.service";
import { IUserDataProfile } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile";
import { IUserDataProfilesService } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile.service";
import { IUserDataProfileStorageService } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfileStorageService.service";
export interface IProfileStorageValueChanges {
    readonly profile: IUserDataProfile;
    readonly changes: IStorageValueChangeEvent[];
}
export interface IProfileStorageChanges {
    readonly targetChanges: IUserDataProfile[];
    readonly valueChanges: IProfileStorageValueChanges[];
}
export interface IStorageValue {
    readonly value: string | undefined;
    readonly target: StorageTarget;
}
export declare abstract class AbstractUserDataProfileStorageService extends Disposable implements IUserDataProfileStorageService {
    protected readonly storageService: IStorageService;
    _serviceBrand: undefined;
    readonly abstract onDidChange: Event<IProfileStorageChanges>;
    private readonly storageServicesMap;
    constructor(persistStorages: boolean, storageService: IStorageService);
    readStorageData(profile: IUserDataProfile): Promise<Map<string, IStorageValue>>;
    updateStorageData(profile: IUserDataProfile, data: Map<string, string | undefined | null>, target: StorageTarget): Promise<void>;
    withProfileScopedStorageService<T>(profile: IUserDataProfile, fn: (storageService: IStorageService) => Promise<T>): Promise<T>;
    private getItems;
    private writeItems;
    protected abstract createStorageDatabase(profile: IUserDataProfile): Promise<IStorageDatabase>;
}
export declare class RemoteUserDataProfileStorageService extends AbstractUserDataProfileStorageService implements IUserDataProfileStorageService {
    private readonly remoteService;
    private readonly _onDidChange;
    readonly onDidChange: Event<IProfileStorageChanges>;
    constructor(persistStorages: boolean, remoteService: IRemoteService, userDataProfilesService: IUserDataProfilesService, storageService: IStorageService, logService: ILogService);
    protected createStorageDatabase(profile: IUserDataProfile): Promise<IStorageDatabase>;
}
