import { Dimension, IDomPosition } from "vscode/vscode/vs/base/browser/dom";
import { ThemeIcon } from "vscode/vscode/vs/base/common/themables";
import { IContextMenuService } from "vscode/vscode/vs/platform/contextview/browser/contextView.service";
import { IInstantiationService } from "vscode/vscode/vs/platform/instantiation/common/instantiation";
import { IStorageService } from "vscode/vscode/vs/platform/storage/common/storage.service";
import { ITelemetryService } from "vscode/vscode/vs/platform/telemetry/common/telemetry.service";
import { IThemeService } from "vscode/vscode/vs/platform/theme/common/themeService.service";
import { IUserDataProfile } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile";
import { EditorPane } from "@codingame/monaco-vscode-9e888134-1a6f-58d9-b0e6-0fc047448366-common/vscode/vs/workbench/browser/parts/editor/editorPane";
import { IEditorOpenContext, IEditorSerializer, IUntypedEditorInput } from "vscode/vscode/vs/workbench/common/editor";
import { EditorInput } from "vscode/vscode/vs/workbench/common/editor/editorInput";
import { IUserDataProfilesEditor } from "../common/userDataProfile.js";
import { IEditorGroup } from "vscode/vscode/vs/workbench/services/editor/common/editorGroupsService";
import { CancellationToken } from "vscode/vscode/vs/base/common/cancellation";
import { IEditorOptions } from "vscode/vscode/vs/platform/editor/common/editor";
import { URI } from "vscode/vscode/vs/base/common/uri";
import { IFileDialogService } from "vscode/vscode/vs/platform/dialogs/common/dialogs.service";
import { IQuickInputService } from "vscode/vscode/vs/platform/quickinput/common/quickInput.service";
import { UserDataProfilesEditorModel } from "./userDataProfilesEditorModel.js";
export declare const profilesSashBorder: string;
export declare class UserDataProfilesEditor extends EditorPane implements IUserDataProfilesEditor {
    private readonly quickInputService;
    private readonly fileDialogService;
    private readonly contextMenuService;
    private readonly instantiationService;
    static readonly ID: string;
    private container;
    private splitView;
    private profilesList;
    private profileWidget;
    private model;
    private templates;
    constructor(group: IEditorGroup, telemetryService: ITelemetryService, themeService: IThemeService, storageService: IStorageService, quickInputService: IQuickInputService, fileDialogService: IFileDialogService, contextMenuService: IContextMenuService, instantiationService: IInstantiationService);
    layout(dimension: Dimension, position?: IDomPosition | undefined): void;
    protected createEditor(parent: HTMLElement): void;
    updateStyles(): void;
    private renderSidebar;
    private renderNewProfileButton;
    private getCreateFromTemplateActions;
    private registerListeners;
    private getTreeContextMenuActions;
    private importProfile;
    createNewProfile(copyFrom?: URI | IUserDataProfile): Promise<void>;
    selectProfile(profile: IUserDataProfile): void;
    private getProfileUriFromFileSystem;
    setInput(input: UserDataProfilesEditorInput, options: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<void>;
    focus(): void;
    private updateProfilesList;
}
export declare class UserDataProfilesEditorInput extends EditorInput {
    private readonly instantiationService;
    static readonly ID: string;
    readonly resource: undefined;
    private readonly model;
    private _dirty;
    get dirty(): boolean;
    set dirty(dirty: boolean);
    constructor(instantiationService: IInstantiationService);
    get typeId(): string;
    getName(): string;
    getIcon(): ThemeIcon | undefined;
    resolve(): Promise<UserDataProfilesEditorModel>;
    isDirty(): boolean;
    save(): Promise<EditorInput>;
    revert(): Promise<void>;
    matches(otherInput: EditorInput | IUntypedEditorInput): boolean;
    dispose(): void;
}
export declare class UserDataProfilesEditorInputSerializer implements IEditorSerializer {
    canSerialize(editorInput: EditorInput): boolean;
    serialize(editorInput: EditorInput): string;
    deserialize(instantiationService: IInstantiationService): EditorInput;
}
