import { CancellationToken } from "vscode/vscode/vs/base/common/cancellation";
import { IExtensionIdentifier } from "vscode/vscode/vs/platform/extensionManagement/common/extensionManagement";
import { IGlobalExtensionEnablementService } from "vscode/vscode/vs/platform/extensionManagement/common/extensionManagement.service";
import { IExtensionManagementService } from "vscode/vscode/vs/platform/extensionManagement/common/extensionManagement.service";
import { IExtensionGalleryService } from "vscode/vscode/vs/platform/extensionManagement/common/extensionManagement.service";
import { IInstantiationService } from "vscode/vscode/vs/platform/instantiation/common/instantiation";
import { ILogService } from "vscode/vscode/vs/platform/log/common/log.service";
import { IUserDataProfile, ProfileResourceType } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile";
import { IUserDataProfileStorageService } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfileStorageService.service";
import { ITreeItemCheckboxState, TreeItemCollapsibleState } from "vscode/vscode/vs/workbench/common/views";
import { IProfileResource, IProfileResourceChildTreeItem, IProfileResourceInitializer, IProfileResourceTreeItem } from "@codingame/monaco-vscode-e72c94ca-257a-5b75-8b68-5a5fa3c18255-common/vscode/vs/workbench/services/userDataProfile/common/userDataProfile";
import { IUserDataProfileService } from "vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service";
interface IProfileExtension {
    identifier: IExtensionIdentifier;
    displayName?: string;
    preRelease?: boolean;
    applicationScoped?: boolean;
    disabled?: boolean;
    version?: string;
}
export declare class ExtensionsResourceInitializer implements IProfileResourceInitializer {
    private readonly userDataProfileService;
    private readonly extensionManagementService;
    private readonly extensionGalleryService;
    private readonly extensionEnablementService;
    private readonly logService;
    constructor(userDataProfileService: IUserDataProfileService, extensionManagementService: IExtensionManagementService, extensionGalleryService: IExtensionGalleryService, extensionEnablementService: IGlobalExtensionEnablementService, logService: ILogService);
    initialize(content: string): Promise<void>;
}
export declare class ExtensionsResource implements IProfileResource {
    private readonly extensionManagementService;
    private readonly extensionGalleryService;
    private readonly userDataProfileStorageService;
    private readonly instantiationService;
    private readonly logService;
    constructor(extensionManagementService: IExtensionManagementService, extensionGalleryService: IExtensionGalleryService, userDataProfileStorageService: IUserDataProfileStorageService, instantiationService: IInstantiationService, logService: ILogService);
    getContent(profile: IUserDataProfile, exclude?: string[]): Promise<string>;
    toContent(extensions: IProfileExtension[], exclude?: string[]): string;
    apply(content: string, profile: IUserDataProfile, progress?: (message: string) => void, token?: CancellationToken): Promise<void>;
    copy(from: IUserDataProfile, to: IUserDataProfile, disableExtensions: boolean): Promise<void>;
    getLocalExtensions(profile: IUserDataProfile): Promise<IProfileExtension[]>;
    getProfileExtensions(content: string): Promise<IProfileExtension[]>;
    private withProfileScopedServices;
}
export declare abstract class ExtensionsResourceTreeItem implements IProfileResourceTreeItem {
    readonly type = ProfileResourceType.Extensions;
    readonly handle = ProfileResourceType.Extensions;
    readonly label: {
        label: string;
    };
    readonly collapsibleState = TreeItemCollapsibleState.Expanded;
    contextValue: ProfileResourceType;
    checkbox: ITreeItemCheckboxState | undefined;
    protected readonly excludedExtensions: Set<string>;
    getChildren(): Promise<Array<IProfileResourceChildTreeItem & IProfileExtension>>;
    hasContent(): Promise<boolean>;
    abstract isFromDefaultProfile(): boolean;
    abstract getContent(): Promise<string>;
    protected abstract getExtensions(): Promise<IProfileExtension[]>;
}
export declare class ExtensionsResourceExportTreeItem extends ExtensionsResourceTreeItem {
    private readonly profile;
    private readonly instantiationService;
    constructor(profile: IUserDataProfile, instantiationService: IInstantiationService);
    isFromDefaultProfile(): boolean;
    protected getExtensions(): Promise<IProfileExtension[]>;
    getContent(): Promise<string>;
}
export declare class ExtensionsResourceImportTreeItem extends ExtensionsResourceTreeItem {
    private readonly content;
    private readonly instantiationService;
    constructor(content: string, instantiationService: IInstantiationService);
    isFromDefaultProfile(): boolean;
    protected getExtensions(): Promise<IProfileExtension[]>;
    getContent(): Promise<string>;
}
export {};
