import { Disposable } from "vscode/vscode/vs/base/common/lifecycle";
import { IConfigurationService } from "vscode/vscode/vs/platform/configuration/common/configuration.service";
import { IDialogService } from "vscode/vscode/vs/platform/dialogs/common/dialogs.service";
import { ILogService } from "vscode/vscode/vs/platform/log/common/log.service";
import { IProductService } from "vscode/vscode/vs/platform/product/common/productService.service";
import { IRequestService } from "vscode/vscode/vs/platform/request/common/request.service";
import { ITelemetryService } from "vscode/vscode/vs/platform/telemetry/common/telemetry.service";
import { IUriIdentityService } from "vscode/vscode/vs/platform/uriIdentity/common/uriIdentity.service";
import { IUserDataProfile, IUserDataProfileOptions, IUserDataProfileUpdateOptions } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile";
import { IUserDataProfilesService } from "vscode/vscode/vs/platform/userDataProfile/common/userDataProfile.service";
import { IWorkspaceContextService } from "vscode/vscode/vs/platform/workspace/common/workspace.service";
import { IWorkbenchEnvironmentService } from "vscode/vscode/vs/workbench/services/environment/common/environmentService.service";
import { IExtensionService } from "vscode/vscode/vs/workbench/services/extensions/common/extensions.service";
import { IHostService } from "vscode/vscode/vs/workbench/services/host/browser/host.service";
import { IProfileTemplateInfo } from "@codingame/monaco-vscode-e72c94ca-257a-5b75-8b68-5a5fa3c18255-common/vscode/vs/workbench/services/userDataProfile/common/userDataProfile";
import { IUserDataProfileManagementService } from "vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service";
import { IUserDataProfileService } from "vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service";
export type ProfileManagementActionExecutedClassification = {
    owner: "sandy081";
    comment: "Logged when profile management action is excuted";
    id: {
        classification: "SystemMetaData";
        purpose: "FeatureInsight";
        comment: "The identifier of the action that was run.";
    };
};
export type ProfileManagementActionExecutedEvent = {
    id: string;
};
export declare class UserDataProfileManagementService extends Disposable implements IUserDataProfileManagementService {
    private readonly userDataProfilesService;
    private readonly userDataProfileService;
    private readonly hostService;
    private readonly dialogService;
    private readonly workspaceContextService;
    private readonly extensionService;
    private readonly environmentService;
    private readonly telemetryService;
    private readonly productService;
    private readonly requestService;
    private readonly configurationService;
    private readonly uriIdentityService;
    private readonly logService;
    readonly _serviceBrand: undefined;
    constructor(userDataProfilesService: IUserDataProfilesService, userDataProfileService: IUserDataProfileService, hostService: IHostService, dialogService: IDialogService, workspaceContextService: IWorkspaceContextService, extensionService: IExtensionService, environmentService: IWorkbenchEnvironmentService, telemetryService: ITelemetryService, productService: IProductService, requestService: IRequestService, configurationService: IConfigurationService, uriIdentityService: IUriIdentityService, logService: ILogService);
    private onDidChangeCurrentProfile;
    private getWorkspaceUri;
    private getProfileToUseForCurrentWorkspace;
    getDefaultProfileToUse(): IUserDataProfile;
    createProfile(name: string, options?: IUserDataProfileOptions): Promise<IUserDataProfile>;
    createAndEnterProfile(name: string, options?: IUserDataProfileOptions): Promise<IUserDataProfile>;
    createAndEnterTransientProfile(): Promise<IUserDataProfile>;
    updateProfile(profile: IUserDataProfile, updateOptions: IUserDataProfileUpdateOptions): Promise<IUserDataProfile>;
    removeProfile(profile: IUserDataProfile): Promise<void>;
    switchProfile(profile: IUserDataProfile): Promise<void>;
    getBuiltinProfileTemplates(): Promise<IProfileTemplateInfo[]>;
    private changeCurrentProfile;
}
