
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Emitter, Event } from 'vscode/vscode/vs/base/common/event';
import 'vscode/vscode/vs/platform/instantiation/common/extensions';
import { ILogService } from 'vscode/vscode/vs/platform/log/common/log.service';
import { AbstractUserDataProfileStorageService } from '../../../../platform/userDataProfile/common/userDataProfileStorageService.js';
import 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import { StorageScope, isProfileUsingDefaultStorage } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { IndexedDBStorageDatabase } from '@codingame/monaco-vscode-2f06fe84-148e-5e6b-a7ca-c7989c5f128a-common/vscode/vs/workbench/services/storage/browser/storageService';
import { IUserDataProfileService } from 'vscode/vscode/vs/workbench/services/userDataProfile/common/userDataProfile.service';
import { DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';

let UserDataProfileStorageService = class UserDataProfileStorageService extends AbstractUserDataProfileStorageService {
    constructor(storageService, userDataProfileService, logService) {
        super(true, storageService);
        this.userDataProfileService = userDataProfileService;
        this.logService = logService;
        this._onDidChange = this._register(( new Emitter()));
        this.onDidChange = this._onDidChange.event;
        const disposables = this._register(( new DisposableStore()));
        this._register(Event.filter(storageService.onDidChangeTarget, e => e.scope === StorageScope.PROFILE, disposables)(() => this.onDidChangeStorageTargetInCurrentProfile()));
        this._register(storageService.onDidChangeValue(StorageScope.PROFILE, undefined, disposables)(e => this.onDidChangeStorageValueInCurrentProfile(e)));
    }
    onDidChangeStorageTargetInCurrentProfile() {
        this._onDidChange.fire({ targetChanges: [this.userDataProfileService.currentProfile], valueChanges: [] });
    }
    onDidChangeStorageValueInCurrentProfile(e) {
        this._onDidChange.fire({ targetChanges: [], valueChanges: [{ profile: this.userDataProfileService.currentProfile, changes: [e] }] });
    }
    createStorageDatabase(profile) {
        return isProfileUsingDefaultStorage(profile) ? IndexedDBStorageDatabase.createApplicationStorage(this.logService) : IndexedDBStorageDatabase.createProfileStorage(profile, this.logService);
    }
};
UserDataProfileStorageService = ( __decorate([
    ( __param(0, IStorageService)),
    ( __param(1, IUserDataProfileService)),
    ( __param(2, ILogService))
], UserDataProfileStorageService));

export { UserDataProfileStorageService };
